@@ -25,7 +25,7 @@ IPC::Run::Debug - debugging routines for IPC::Run
 =head1 DESCRIPTION
 
 Controls IPC::Run debugging.  Debugging levels are now set by using words,
-but the numbers shown are still supported for backwards compatability:
+but the numbers shown are still supported for backwards compatibility:
 
    0  none         disabled (special, see below)
    1  basic        what's running
@@ -70,7 +70,7 @@ use strict;
 use Exporter;
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS};
 BEGIN {
-	$VERSION = '0.81_01';
+	$VERSION = '0.90_01';
 	@ISA     = qw( Exporter );
 	@EXPORT  = qw(
 		_debug
@@ -118,7 +118,6 @@ sub _debugging_not_optimized() { 0 }
 STUBS
 
 use POSIX;
-use UNIVERSAL qw( isa );
 
 sub _map_fds {
    my $map = '';
@@ -269,7 +268,7 @@ sub _debug_desc_fd {
    my $op = pop;
    my $kid = $_[0];
 
-Carp::carp join " ", caller(0), $text, $op  if defined $op  && isa( $op, "IO::Pty" );
+Carp::carp join " ", caller(0), $text, $op  if defined $op  && UNIVERSAL::isa( $op, "IO::Pty" );
 
    _debug(
       $text,
