@@ -1,7 +1,5 @@
 package IPC::Run::IO;
 
-=pod
-
 =head1 NAME
 
 IPC::Run::IO -- I/O channels for IPC::Run.
@@ -48,7 +46,7 @@ to do this.>
 =head1 DESCRIPTION
 
 This class and module allows filehandles and filenames to be harnessed for
-I/O when used IPC::Run, independant of anything else IPC::Run is doing
+I/O when used IPC::Run, independent of anything else IPC::Run is doing
 (except that errors & exceptions can affect all things that IPC::Run is
 doing).
 
@@ -57,14 +55,6 @@ doing).
 INCOMPATIBLE CHANGE: due to the awkwardness introduced in ripping pseudohashes
 out of Perl, this class I<no longer> uses the fields pragma.
 
-=head1 TODO
-
-Implement bidirectionality.
-
-=head1 AUTHOR
-
-Barrie Slaymaker <barries@slaysys.com>
-
 =cut
 
 ## This class is also used internally by IPC::Run in a very initimate way,
@@ -76,14 +66,13 @@ use strict;
 use Carp;
 use Fcntl;
 use Symbol;
-use UNIVERSAL ();
 
 use IPC::Run::Debug;
 use IPC::Run qw( Win32_MODE );
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.81_01';
+	$VERSION = '0.90_01';
 	if ( Win32_MODE ) {
 		eval "use IPC::Run::Win32Helper; require IPC::Run::Win32IO; 1"
 		or ( $@ && die ) or die "$!";
@@ -93,6 +82,18 @@ BEGIN {
 sub _empty($);
 *_empty = \&IPC::Run::_empty;
 
+=head1 SUBROUTINES
+
+=over 4
+
+=item new
+
+I think it takes >> or << along with some other data.
+
+TODO: Needs more thorough documentation. Patches welcome.
+
+=cut
+
 sub new {
    my $class = shift;
    $class = ref $class || $class;
@@ -306,7 +307,7 @@ sub open {
 =item open_pipe
 
 If this is a redirection IO object, this opens the pipe in a platform
-independant manner.
+independent manner.
 
 =cut
 
@@ -402,8 +403,6 @@ sub fileno {
    return $fd;
 }
 
-=pod
-
 =item mode
 
 Returns the operator in terms of 'r', 'w', and 'a'.  There is a state
@@ -511,6 +510,13 @@ confess "\$self not an IPC::Run::IO" unless UNIVERSAL::isa( $self, "IPC::Run::IO
    push @{$self->{FBUFS}}, $self->{SOURCE};
 }
 
+=item poll
+
+TODO: Needs confirmation that this is correct. Was previously undocumented.
+
+I believe this is polling the IO for new input and then returns undef if there will never be any more input, 0 if there is none now, but there might be in the future, and TRUE if more input was gotten.
+
+=cut
 
 sub poll {
    my IPC::Run::IO $self = shift;
@@ -545,14 +551,17 @@ sub _do_filters {
    my ( $saved_op, $saved_num ) =($IPC::Run::filter_op,$IPC::Run::filter_num);
    $IPC::Run::filter_op = $self;
    $IPC::Run::filter_num = -1;
-   my $c = 0;
+   my $redos = 0;
    my $r;
    {
 	   $@ = '';
 	   $r = eval { IPC::Run::get_more_input(); };
-	   $c++;
-	   ##$@ and warn "redo ", substr($@, 0, 20) , " ";
-	   (($c < 200) and ($@||'')=~ m/^Resource temporarily/) and redo;
+
+	   # Detect Resource temporarily unavailable and re-try to a point (200 or 2 seconds),  assuming select behaves (which it doesn't always? need ref)
+	   if($@ && $@ =~ m/^Resource temporarily/ && $redos++ < 200) {
+	       select(undef, undef, undef, 0.01);
+	       redo;
+	   }
    }
    ( $IPC::Run::filter_op, $IPC::Run::filter_num ) = ( $saved_op, $saved_num );
    $self->{HARNESS} = undef;
@@ -560,4 +569,16 @@ sub _do_filters {
    return $r;
 }
 
+=back
+
+=head1 AUTHOR
+
+Barrie Slaymaker <barries@slaysys.com>
+
+=head1 TODO
+
+Implement bidirectionality.
+
+=cut
+
 1;
